@@ -1,4 +1,5 @@
-use reef::{Command, Result};
+use anyhow::Result;
+use reef::Command;
 
 fn main() -> Result<()> {
     let path = std::env::temp_dir().join("command-times.json");
