@@ -12,18 +12,18 @@ fn main() {
 
     let clone = Command::new(&format!("git clone {} raykit.git", url))
         .directory(&path)
-        .exec();
+        .exec(); //,exec_in(&path);
     println!("{:#?}", &clone);
 
     let raykit = path.join("raykit.git");
     assert!(raykit.exists(), "{} does not exist", raykit.display());
 
-    let pull = Command::new("git pull").directory(&raykit).exec();
+    let pull = Command::new("git pull").directory(&raykit).exec(); //exec_in(&raykit);
     println!("{:#?}", &pull);
 
     let log = Command::new("git log -1 --oneline")
         .directory(&raykit)
-        .exec();
+        .exec(); //exec_in(&raykit);
     println!("{:#?}", &log);
 
     Paths::clobber(&path).unwrap();
