@@ -1,6 +1,7 @@
 //use assert_cmd::prelude::*; // Add methods on commands
 //use predicates::prelude::*;
-use reef::{Command, Result};
+use anyhow::Result;
+use reef::Command;
 //use std::process::Command; // Run programs // Used for writing assertions
 
 //#[test]
