@@ -1,4 +1,5 @@
-use crate::{Env, Error, ErrorKind, Paths, Result, Status};
+use crate::{Env, Paths, Status};
+use anyhow::{anyhow, Result};
 use chrono::prelude::*;
 use colored::*;
 use log::{info, trace, warn};
@@ -55,6 +56,19 @@ impl Command {
         c
     }
 
+    pub fn stdout(&self) -> Result<String> {
+        if self.stdout.len() > 0 {
+            Ok(self.stdout.clone())
+        } else {
+            let c = self.exec()?;
+            if c.exit_code == 0 {
+                Ok(c.stdout.clone())
+            } else {
+                Err(anyhow!("exit code was {}", c.exit_code))
+            }
+        }
+    }
+
     pub fn arg(&self, arg: &str) -> Command {
         let mut c = self.clone();
         c.args.push(arg.to_string());
@@ -192,10 +206,7 @@ impl Command {
         if self.exit_code == exit_code {
             Ok(self.clone())
         } else {
-            Err(Error::from_kind(ErrorKind::IncorrectExitCode(
-                exit_code,
-                format!("{}", &self),
-            )))
+            Err(anyhow!("incorrect exist code {}", exit_code))
         }
     }
 
@@ -203,7 +214,8 @@ impl Command {
         let mut dir = PathBuf::new();
         dir.push(&self.working_dir);
         if !dir.exists() {
-            return Err(Error::from_kind(ErrorKind::PathDoesNotExist(dir)));
+            return Err(anyhow!("path does not exist {:#?}", dir));
+            //return Err(Error::from_kind(ErrorKind::PathDoesNotExist(dir)));
         }
 
         let exe_filename = Env::which(&self.name)?;
@@ -229,9 +241,7 @@ impl Command {
     // TODO: add timeout support: https://docs.rs/wait-timeout/0.2.0/wait_timeout/
     pub fn exec(&self) -> Result<Command> {
         if !&self.working_dir.exists() {
-            return Err(Error::from_kind(ErrorKind::PathDoesNotExist(
-                self.working_dir.to_path_buf(),
-            )));
+            return Err(anyhow!("path does not exist {:#?}", self.working_dir));
         }
 
         let mut process_command = self.get_std()?;
@@ -244,51 +254,8 @@ impl Command {
         let mut dir = PathBuf::new();
         dir.push(&self.working_dir);
 
-        /*
-        let command_path = Env::which(&command.name)?;
-        command.exe_filename = Paths::which(&command.name)?; // format!("{}", Paths::which(&command.name).unwrap().display());
-        let mut process_command = std::process::Command::new(&command.exe_filename);
-        command.start = Utc::now().to_string();
-        process_command.current_dir(&command.working_dir);
-        debug!("directory={}", &command.working_dir.display());
-        debug!("command={} {}", &command.name, &command.args.join(" "));
-        let ext = Paths::extension(&command_path);
-        if ext == "bat" || ext == "cmd" {
-            command.exe_filename = Paths::which("cmd")?;
-            //command.path = format!("{}", Paths::which("cmd").unwrap().display());
-            process_command =
-                std::process::Command::new(&format!("{}", Paths::which("cmd").unwrap().display()));
-            process_command.current_dir(&command.working_dir);
-
-            let mut args: Vec<String> = Vec::new();
-            args.push("/C".to_string());
-            args.push(format!("{}", command_path.display()));
-            args.append(&mut command.args.clone());
-            process_command.args(crate::text::get_vec_osstring(&args.clone()));
-        } else {
-            process_command.current_dir(&command.working_dir);
-            process_command.args(crate::text::get_vec_osstring(&command.args.clone()));
-        }*/
-
         trace!("timeout={:?}", self.timeout);
 
-        /*
-        let mut child = process_command.spawn()?;
-        let mut _spinner: Option<Spinner> = None;
-        if self.spinner {
-            _spinner = Some(Spinner::new(&format!(
-                "executing {} {}...",
-                command.name,
-                command.args.join(" ")
-            )));
-        }*/
-        // match child.wait_timeout(self.timeout)? {
-        //     Some(status) => {
-        //         trace!("status={}", status);
-        //         command.status = match status.success() {
-        //             true => Status::Ok,
-        //             false => Status::Error,
-        //         };
         command.start = Utc::now().to_string();
         let output = process_command.output()?;
         command.exit_code = match output.status.code() {
@@ -308,7 +275,7 @@ impl Command {
         };
         trace!("stderr={}", command.stderr);
 
-        command.duration = now.elapsed().clone(); // Duration::from_std(&now.elapsed()).unwrap();
+        command.duration = now.elapsed().clone();
         command.status = match output.status.success() {
             true => {
                 info!("{}", &command.summary());
@@ -319,18 +286,6 @@ impl Command {
                 Status::Error
             }
         };
-        //    }
-        //    None => {
-        //        warn!(
-        //            "timeout of {} exceeded",
-        //            &crate::duration::format(&command.timeout)
-        //        );
-        //        child.kill()?;
-        //        child.wait()?;
-        //        command.stderr = "timed out".to_string();
-        //        command.exit_code = 99;
-        //    }
-        //}
 
         Ok(command)
     }
@@ -360,7 +315,6 @@ impl Display for Command {
         Ok(())
     }
 }
-impl std::error::Error for Command {}
 
 impl PartialOrd for Command {
     fn partial_cmp(&self, other: &Command) -> Option<Ordering> {
