@@ -29,23 +29,12 @@ assert!(git_version.stdout.contains("git version"));
 
 */
 
-#![crate_name = "reef"]
-
-#[macro_use]
-extern crate error_chain;
 pub mod duration;
 pub use crate::duration::Duration;
-mod errors;
-pub use crate::errors::Error;
-pub use crate::errors::ErrorKind;
-pub use crate::errors::Result;
 
 mod log;
 pub use crate::log::Log;
 
-//mod spinner;
-//pub use crate::spinner::Spinner;
-
 mod secrets;
 pub use crate::secrets::Secrets;
 
